@@ -863,7 +863,7 @@ char *unescape_newlines(char *rawbuf) {
 				}
 
 			/* unescape backslashes and other stuff */
-			if(rawbuf[x + 1] != '\x0') {
+      else if(rawbuf[x + 1] != '\x0') {
 				rawbuf[y++] = rawbuf[x + 1];
 				x++;
 				}
@@ -1080,7 +1080,7 @@ const char *url_encode(const char *input) {
 		else {
 			str[y] = '\x0';
 			if((int)strlen(str) < (output_len - 3)) {
-				sprintf(temp_expansion, "%%%02X", (unsigned char)input[x]);
+					sprintf(temp_expansion, "%%%02X", (unsigned int)(input[x] & 0xFF));
 				strcat(str, temp_expansion);
 				y += 3;
 				}
@@ -1138,6 +1138,7 @@ char * html_encode(char *input, int escape_newlines) {
 	char		*outstp;
 	wchar_t		*wcinput;
 	wchar_t		*inwcp;
+	wchar_t		*tagname = L"";
 	size_t		mbstowcs_result;
 	int			x;
 	int			where_in_tag = WHERE_OUTSIDE_TAG; /* Location in HTML tag */
@@ -1176,6 +1177,7 @@ char * html_encode(char *input, int escape_newlines) {
 				switch(*inwcp) {
 				case 0x20:
 					where_in_tag = WHERE_IN_TAG_OUTSIDE_ATTRIBUTE;
+					*inwcp = 0;
 					break;
 				case '!':
 					where_in_tag = WHERE_IN_COMMENT;
@@ -1248,7 +1250,10 @@ char * html_encode(char *input, int escape_newlines) {
 					}
 				break;
 			default:
-				outstp = encode_character(*inwcp, outstp, output_max);
+				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
+					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				else
+					outstp = encode_character(*inwcp, outstp, output_max);
 				break;
 				}
 			}
@@ -1280,11 +1285,15 @@ char * html_encode(char *input, int escape_newlines) {
 					break;
 				default:
 					tag_depth++;
+					tagname = inwcp + 1;
 					break;
 					}
 				break;
 			default:
-				outstp = encode_character(*inwcp, outstp, output_max);
+				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
+					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				else
+					outstp = encode_character(*inwcp, outstp, output_max);
 				break;
 				}
 			}
@@ -1295,8 +1304,10 @@ char * html_encode(char *input, int escape_newlines) {
 			case WHERE_IN_TAG_NAME:
 			case WHERE_IN_TAG_OUTSIDE_ATTRIBUTE:
 			case WHERE_IN_COMMENT:
+			case WHERE_IN_TAG_IN_ATTRIBUTE_NAME:
 				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
 				where_in_tag = WHERE_OUTSIDE_TAG;
+				*inwcp = 0;
 				break;
 			case WHERE_IN_TAG_IN_ATTRIBUTE_VALUE:
 				if((attr_value_start != '"') && (attr_value_start != '\'')) {
@@ -1308,11 +1319,22 @@ char * html_encode(char *input, int escape_newlines) {
 					}
 				break;
 			default:
-				outstp = encode_character(*inwcp, outstp, output_max);
+				if (tag_depth > 0 && !wcscmp(tagname, L"script"))
+					outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+				else
+					outstp = encode_character(*inwcp, outstp, output_max);
 				break;
 				}
 			}
 
+		/* check_multi puts out a '&ndash' so don't encode the '&' in that case */
+		else if (*inwcp == '&' && escape_html_tags == FALSE) {
+			if (tag_depth > 0 && !wcsncmp(inwcp, L"&ndash", 6))
+				outstp = copy_wc_to_output(*inwcp, outstp, output_max);
+			else
+				outstp = encode_character(*inwcp, outstp, output_max);
+			}
+
 		/* for simplicity, all other chars represented by their numeric value */
 		else {
 			outstp = encode_character(*inwcp, outstp, output_max);
